(ns puppetlabs.activity.http.util
  (:require
    [clojure.tools.logging :as log]
    [clojure.data.csv :as csv]
    [cheshire.core :as json])
  (:import java.io.StringWriter))

(defn response
  [status data]
  {:status  status
   :headers {"Content-Type" "application/json"}
   :body    (json/encode data)})

(defn csv-response
  [status data filename]
  {:status  status
   :headers {"Cache-Control"       "Cache-Control: max-age=0, private, must-revalidate",
             "Content-Type"        "text/csv",
             "Content-Disposition" (str "attachment; filename=" filename)}
   :body    (with-open [writer (StringWriter.)]
              (csv/write-csv writer data)
              (.toString writer))})

(defn csv-filename
  [{:keys [subject_type subject_id object_type object_id] :as params}]

  (cond
    (and subject_type subject_id) (format "activities-for-subject-%s-%s.csv" subject_type subject_id)
    (and object_type object_id) (format "activities-for-%s-%s.csv" object_type object_id)
    :else "activities.csv"))
