-- PostgreSQL function for moving old data from DB to a CSV file:

CREATE FUNCTION backup_activity_events(threshold timestamp with time zone, filename text)
  RETURNS void AS
$$
DECLARE
  threshold_time timestamp with time zone;

BEGIN

  -- threshold_time is used to make sure that the same records are stored and removed
  EXECUTE '
    SELECT max(submit_time)
      FROM event_commits
      WHERE submit_time < $1'
  INTO threshold_time
  USING threshold;

  IF threshold_time is null THEN return;
  END IF;

  EXECUTE '
    COPY
      (SELECT ec.submit_time        AS "Submit Time",
              ec.service_id         AS "Service Id",
              sd.subject_type       AS "Subject Type",
              sd.subject_id         AS "Subject Id",
              sd.subject_name       AS "Subject Name",
              od.object_type        AS "Object Type",
              od.object_id          AS "Object Id",
              od.object_name        AS "Object Name",
              ev.action_type        AS "Type",
              ev.action_what        AS "What",
              ev.action_description AS "Description",
              ev.message            AS "Message"
         FROM event_commits AS ec
         JOIN events AS ev ON ev.commit_id = ec.id
         JOIN subject_digests AS sd ON sd.id = ec.subject_digest_id
         JOIN object_digests AS od ON od.id = ec.object_digest_id
         WHERE ec.submit_time <= ''' || threshold_time || '''
         ORDER BY ec.submit_time, ev.action_type, ev.action_what)
      TO ''' || filename || '''
      WITH CSV HEADER';

  -- DELETE command could be called directly (without EXECUTE), however, it's better to call it the same way as the COPY TO command above
  EXECUTE '
    DELETE FROM event_commits
      WHERE submit_time <= ''' || threshold_time || '''';

END
$$
LANGUAGE 'plpgsql';
